@@ -93,6 +93,7 @@ static char *std_deco_tb[] = {
 	"emphasis 3 accent 7 4 4",
 	"lowermordent 3 lmrd 10 2 2",
 	"coda 3 coda 24 10 10",
+	"dacoda 3 dacoda 16 10 10",
 	"uppermordent 3 umrd 10 2 2",
 	"segno 3 sgno 20 4 4",
 	"trill 3 trl 11 4 4",
@@ -121,7 +122,12 @@ static char *std_deco_tb[] = {
 	"marcato 3 marcato 9 3 3",
 	"^ 3 marcato 9 3 3",
 	"D.C. 3 dacs 16 10 10 D.C.",
+	"D.C.alcoda 3 dacs 16 10 10 D.C. al Coda",
+	"D.C.alfine 3 dacs 16 10 10 D.C. al Fine",
+	"dacapo 3 dacs 16 10 10 Da Capo",
 	"D.S. 3 dacs 16 10 10 D.S.",
+	"D.S.alcoda 3 dacs 16 10 10 D.S. al Coda",
+	"D.S.alfine 3 dacs 16 10 10 D.S. al Fine",
 	"fine 3 dacs 16 10 10 FINE",
 	"f 6 pf 18 1 7",
 	"ff 6 pf 18 2 10",
